---
external help file: SitecoreFundamentals-help.xml
Module Name: SitecoreFundamentals
online version: 
schema: 2.0.0
---

# Remove-WebFeatureSSL

## SYNOPSIS
Removes the SSL web feature.

## SYNTAX

```
Remove-WebFeatureSSL [-HostName] <String> [-Port <Int32>] [-Issuer <String>] [-WhatIf] [-Confirm]
 [<CommonParameters>]
```

## DESCRIPTION
This cmdlet removes the SSL web feature from the website specified by the HostName parameter.

## EXAMPLES

### -------------------------- EXAMPLE 1 --------------------------
```
PS C:\> Remove-WebFeatureSSL -HostName sc.infosec -Verbose
```

This command removes the SSL binding and client certificate for the 'sc.infosec' website using default settings for root CA and certificate naming.

### -------------------------- EXAMPLE 2 --------------------------
```
PS C:\> Remove-WebFeatureSSL `
                  -HostName sc.infosec \`
                  -Port 443 \`
                  -Issuer 'CN=DO_NOT_TRUST_SitecoreFundamentalsRoot'
```

This command removes the SSL binding and client certificate for the 'sc.infosec' website.

## PARAMETERS

### -HostName
Hostname of website to configure.

```yaml
Type: String
Parameter Sets: (All)
Aliases: 

Required: True
Position: 0
Default value: None
Accept pipeline input: False
Accept wildcard characters: False
```

### -Issuer
Subject Name for certificate.
Value should be in the form 'CN=\<issuer name\>'.

```yaml
Type: String
Parameter Sets: (All)
Aliases: 

Required: False
Position: Named
Default value: CN=DO_NOT_TRUST_SitecoreFundamentalsRoot
Accept pipeline input: False
Accept wildcard characters: False
```

### -Port
HTTPS Port number.

```yaml
Type: Int32
Parameter Sets: (All)
Aliases: 

Required: False
Position: Named
Default value: 443
Accept pipeline input: False
Accept wildcard characters: False
```

### -Confirm
Prompts you for confirmation before running the cmdlet.

```yaml
Type: SwitchParameter
Parameter Sets: (All)
Aliases: cf

Required: False
Position: Named
Default value: None
Accept pipeline input: False
Accept wildcard characters: False
```

### -WhatIf
Shows what would happen if the cmdlet runs. The cmdlet is not run.

```yaml
Type: SwitchParameter
Parameter Sets: (All)
Aliases: wi

Required: False
Position: Named
Default value: None
Accept pipeline input: False
Accept wildcard characters: False
```

### CommonParameters
This cmdlet supports the common parameters: -Debug, -ErrorAction, -ErrorVariable, -InformationAction, -InformationVariable, -OutVariable, -OutBuffer, -PipelineVariable, -Verbose, -WarningAction, and -WarningVariable. For more information, see about_CommonParameters (http://go.microsoft.com/fwlink/?LinkID=113216).

## INPUTS

### None

## OUTPUTS

### None

## NOTES

## RELATED LINKS

[Add-WebFeatureSSL](Add-WebFeatureSSL.md)

[Test-WebFeatureSSL](Test-WebFeatureSSL.md)

